@@ -16,12 +16,12 @@ set -o xtrace
 
 # Set up default repos
 MURANO_REPO=${MURANO_REPO:-${GIT_BASE}/openstack/murano.git}
-MURANO_BRANCH=${MURANO_BRANCH:-master}
+MURANO_BRANCH=${MURANO_BRANCH:-stable/liberty}
 
 # Variables, which used in this function
 # https://github.com/openstack-dev/devstack/blob/master/functions-common#L500-L506
 GITREPO["python-muranoclient"]=${MURANO_PYTHONCLIENT_REPO:-${GIT_BASE}/openstack/python-muranoclient.git}
-GITBRANCH["python-muranoclient"]=${MURANO_PYTHONCLIENT_BRANCH:-master}
+GITBRANCH["python-muranoclient"]=${MURANO_PYTHONCLIENT_BRANCH:-stable/liberty}
 GITDIR["python-muranoclient"]=$DEST/python-muranoclient
 
 # Set up default directories
@@ -42,7 +42,6 @@ MURANO_KEYSTONE_SIGNING_DIR=${MURANO_KEYSTONE_SIGNING_DIR:-/tmp/keystone-signing
 
 MURANO_DEFAULT_ROUTER=${MURANO_DEFAULT_ROUTER:-''}
 MURANO_EXTERNAL_NETWORK=${MURANO_EXTERNAL_NETWORK:-''}
-MURANO_DEFAULT_DNS=${MURANO_DEFAULT_DNS:-''}
 
 # MURANO_RABBIT_VHOST allows to specify a separate virtual host for Murano services.
 # This is not required if all OpenStack services are deployed by devstack scripts
@@ -135,10 +134,6 @@ function configure_murano_networking {
     if [[ -n "$MURANO_DEFAULT_ROUTER" ]]; then
         iniset $MURANO_CONF_FILE networking router_name $MURANO_DEFAULT_ROUTER
     fi
-
-    if [[ -n "$MURANO_DEFAULT_DNS" ]]; then
-        iniset $MURANO_CONF_FILE networking default_dns $MURANO_DEFAULT_DNS
-    fi
 }
 
 # Entry points
@@ -275,7 +270,7 @@ HORIZON_LOCAL_CONFIG=${HORIZON_LOCAL_CONFIG:-$HORIZON_DIR/openstack_dashboard/lo
 
 # Set up default repos
 MURANO_DASHBOARD_REPO=${MURANO_DASHBOARD_REPO:-${GIT_BASE}/openstack/murano-dashboard.git}
-MURANO_DASHBOARD_BRANCH=${MURANO_DASHBOARD_BRANCH:-master}
+MURANO_DASHBOARD_BRANCH=${MURANO_DASHBOARD_BRANCH:-stable/liberty}
 
 # Set up default directories
 MURANO_DASHBOARD_DIR=$DEST/murano-dashboard
@@ -283,11 +278,24 @@ MURANO_PYTHONCLIENT_DIR=$DEST/python-muranoclient
 
 MURANO_DASHBOARD_CACHE_DIR=${MURANO_DASHBOARD_CACHE_DIR:-/tmp/murano}
 
-MURANO_REPOSITORY_URL=${MURANO_REPOSITORY_URL:-'http://storage.apps.openstack.org/'}
+MURANO_REPOSITORY_URL=${MURANO_REPOSITORY_URL:-'http://apps.openstack.org/api/v1/murano_repo/liberty/'}
 
 # Functions
 # ---------
 
+function insert_config_block() {
+    local target_file="$1"
+    local insert_file="$2"
+    local pattern="$3"
+
+    if [[ -z "$pattern" ]]; then
+        cat "$insert_file" >> "$target_file"
+    else
+        sed -ne "/$pattern/r  $insert_file" -e 1x  -e '2,${x;p}' -e '${x;p}' -i "$target_file"
+    fi
+}
+
+
 function remove_config_block() {
     local config_file="$1"
     local label="$2"
@@ -305,13 +313,14 @@ function remove_config_block() {
 function configure_murano_dashboard() {
     remove_config_block "$HORIZON_CONFIG" "MURANO_CONFIG_SECTION"
 
+    configure_settings_py
     configure_local_settings_py
 
     restart_apache_server
 }
 
 
-function configure_local_settings_py() {
+function configure_settings_py() {
     local horizon_config_part=$(mktemp)
 
     mkdir_chown_stack "$MURANO_DASHBOARD_CACHE_DIR"
@@ -329,22 +338,28 @@ DATABASES = {
     }
 }
 SESSION_ENGINE = 'django.contrib.sessions.backends.db'
+MIDDLEWARE_CLASSES += ('muranodashboard.middleware.ExceptionMiddleware',)
 MURANO_REPO_URL = '$MURANO_REPOSITORY_URL'
 #-------------------------------------------------------------------------------
 #MURANO_CONFIG_SECTION_END
 
 EOF
 
-    cat "$horizon_config_part" >> "$HORIZON_LOCAL_CONFIG"
+    # Insert changes into dashboard config before the line matching the pattern
+    insert_config_block "$HORIZON_CONFIG" "$horizon_config_part" "from openstack_dashboard import policy"
 
+    # Install Murano as plugin for Horizon
+    ln -sf $MURANO_DASHBOARD_DIR/muranodashboard/local/_50_murano.py $HORIZON_DIR/openstack_dashboard/local/enabled/
+}
+
+
+function configure_local_settings_py() {
     if [[ -f "$HORIZON_LOCAL_CONFIG" ]]; then
         sed -e "s/\(^\s*OPENSTACK_HOST\s*=\).*$/\1 '$HOST_IP'/" -i "$HORIZON_LOCAL_CONFIG"
     fi
-
-    # Install Murano as plugin for Horizon
-    ln -s $MURANO_DASHBOARD_DIR/muranodashboard/local/_50_murano.py $HORIZON_DIR/openstack_dashboard/local/enabled/
 }
 
+
 # init_murano_dashboard() - Initialize databases, etc.
 function init_murano_dashboard() {
     # clean up from previous (possibly aborted) runs
@@ -354,7 +369,7 @@ function init_murano_dashboard() {
 
     python "$horizon_manage_py" collectstatic --noinput
     python "$horizon_manage_py" compress --force
-    python "$horizon_manage_py" migrate --noinput
+    python "$horizon_manage_py" syncdb --noinput
 
     restart_apache_server
 }
@@ -427,3 +442,4 @@ fi
 
 # Restore xtrace
 $XTRACE
+
